<?php

/**
 * PHP třída
 * Každá třída je uložena ve vlastním souboru, který má stejná název jako třída samotná
 * Názvy tříd zahajujeme velkým písmenem a název volíme podle charakteru a ucelu
 * Celý obsah třídy je obalen ve složených závorkách
 * Třída je vlastně definični kostrou pro objekty, které z této třídy vzniknou
 * V naší aplikaci je z této třídy inicializovan jeden objekt v souboru index 
 */
class Menu {
    
    // Třídy mohou (nemusí) definovat své vlastnosti
    // Např. třída Clovek - vlastnosti: datum nar, pohlavi, výška, hmotnost, barva vlasů, barva oci, ...
    
    /**
     * Vlastnosti třídy menu
     * porovnejte přístupové modifikátory Public, Private, Protected
     * https://www.w3schools.com/php/php_oop_access_modifiers.asp
     */
    private $items = array();
    
    private $active_item;
   
    
    
    
    // Třídy mohou (nemusí) definovat své metody
    // Metody jsou vlastne funkce, kterým se ale v OOP ríká metody
    // Metodami objekty interagují se svým okolím
    // Např. třída Clovek - metody: mluv(), stuj(), bez(), sedni(), ...

    /**
     * Metoda, pomoci ktere lze objektu třídy přidat polozku menu
     */
    public function addMenuItem($page_url, $page_title) 
    {
        $this->items[$page_url] = $page_title;
    }
    
    
    /**
     * Metoda, kterou objekt vrací své polozky menu
     */
    public function getMenuItems() 
    {
        return $this->items;
    }
    
    
    /**
     * Metoda, pomocí které lze objektu nastavit aktuální polozku menu
     */
    public function setActiveItem($page) 
    {       
        if (array_key_exists($page, $this->items)) {
            $this->active_item = $page;
        } else {
            $this->active_item = DEFAULT_PAGE_URL;
        }
    }
    
    
    /**
     * Metoda, kterou objekt třídy vrací nastavenou aktivni polozku menu
     */
    public function getActiveItem() 
    {
        return $this->active_item;
    }
    
    
    
    /**
     * Pomocná metoda, která nám vrací titulek
     */
    public function getPageTitle() 
    {
        return $this->items[$this->active_item];
    }
    
    
    /**
     * Pomocná metoda, která nám vrací retezec odkazu polozky menu
     * Volá se pri vykresleni menu v souboru head.inc.php
     */
    public function createLink($key) 
    {
        if ($key === DEFAULT_PAGE_NAME) {
            return SERVER;
        }
        return SERVER . '?page='.$key;
    }
}


