<?php

/**
 * Jednoduchá třída odeslání emailu
 * V praxi bych ale spíše doporučil využít nějakou hotovou komponentu 
 * Např. sendMail z PHP frameworku Nette, kde jsou mnohem komplexněji řešeny bezpečnostní i funkční aspekty odesílání emailu
 */

class Sendmail {
    
    // Vlastnosti třídy
    private $recipient_email;
    private $subject;
    private $headers;    
    
    private $sender_var = array();      
    private $errors = array();
   
    
    /* 
     * Metoda z názvem set na začátku svého názvu většinou nstavuje vlastnosti
     */    
    public function setRecipientEmail($email) 
    {
        if (filter_var($email, FILTER_VALIDATE_EMAIL)) {
            $this->recipient_email = $email;
        }
        else {
            $this->setError("Email příjemce není zadán nebo není validní");
        }
    }
    
    
    public function setSubject($subject) 
    {
        $this->subject = filter_var($subject, FILTER_SANITIZE_STRING);
    }
    

    public function setHeaders() 
    {
        $this->headers  =   "From: =?utf-8?B?" . base64_encode($this->getSenderVar('sender_name')) . "?= <".$this->getSenderVar('sender_email').">\n";
        $this->headers .=   "MIME-Version: 1.0\n".
                            "Content-Type: text/html; charset=\"utf-8\"\n".
                            "Content-Transfer-Encoding: base64\n".
                            "X-Priority: 3 (Normal)\n".
                            "X-MSMail-Priority: Normal\n".
                            "Importance: Normal\n";
        $this->headers .=   "Return-Path: <".$this->getSenderVar('sender_email').">";
    }
    
    
    public function setParamsFromSender() 
    {
        $params = filter_input_array(INPUT_POST);
        
        foreach ($params as $key => $value) {
            switch ($key) {
                case "sender_name":
                   $this->setSenderName($key, $value);
                break;
            
                case "sender_email":
                    $this->setSenderEmail($key, $value);
                break;
            
                case "message":
                    $this->setMessage($key, $value);
                break;
            
                default: "";
                break;
            
            }
        }
    }
    

    /* 
     * Privátní settery
     * Private - možno volat pouze uvnitř třídy
     */
    private function setSenderName($var, $value) 
    {
        if ($value) {
            $this->sender_var[$var] = filter_var($value, FILTER_SANITIZE_STRING);
        }
        else {
            $this->setError("Jméno není zadáno");
        }
    }
    
    
    private function setSenderEmail($var, $value) 
    {
        if (filter_var($value, FILTER_VALIDATE_EMAIL)) {
            $this->sender_var[$var] = $value;
        }
        else {
            $this->setError("Email není zadán nebo není validní");
            $this->sender_var[$var] = $value;
        }
    }
    
    
    private function setMessage($var, $value) 
    {
        if ($value) {
            $this->sender_var[$var] = chunk_split(Base64_Encode(stripslashes(trim($value))));
        }
        else {
            $this->setError("Není vyplněna zpráva");  
        }       
    }
    
    
    private function setError($param) 
    {
        $this->errors[] = $param;
    }
    
    
    /*
     * Metoda zodopovědná za odeslání emailu
     */  
    public function sendEmail() 
    {
        if (!$this->errors) {
            if (mail($this->recipient_email, $this->subject, $this->sender_var['message'], $this->headers)) {            
                return true;
            }
            else {
               $this->setError("Email nebyl odeslán. Zkuste to prosím později. Chyba není na Vaší straně");
               return false;
            }           
        }
        return false;

    }
    
    
    public function getErrors() 
    {
        return $this->errors;
    }
    
    
    public function getSenderVar($key) 
    {
        if (array_key_exists($key, $this->sender_var)) {
            return $this->sender_var[$key];
        }
        return null;
    }
        
    
}