<?php
// Toto jsou jednořádkové komentáře ve zdrojovém kódu PHP
/**
 * Toto je víceřádkový komentář PHP
 */ 

// Soubor Index.php sestavuje požadované soubory a je jediný přístupný bod naší aplikace
// Soubor Index.php neobsahuje žádné přímo vložené HTML! 
// Sestavuje aplikaci na základě informací příchozího požadavku, resp. jeho URL

// DEFINICE KONSTANT, Co je to konstanta? Co je pro ni charakteristické?
// Konstantu SERVER nezapomeňte změnit v případě použití na veřejném webhostingu!!!
define('SERVER', "http://localhost/project/");
define('WEBNAME', "Projekt zápočtové práce");
define('DEFAULT_PAGE_NAME', "titulka");

// Z tzv. superglobálního pole GET získáme hodnotu proměnné $_GET['page']
// Tato proměnná je vlastně součástí URL požadavku, např. http://localhost/projekt?page=hodnotaPromennePage
// K získání hodnoty této proměnné z ULR použijeme funkci filter_input()
$page = filter_input(INPUT_GET, "page", FILTER_SANITIZE_ENCODED);

// Provedeme kontrolu hodnoty této proměnné, resp. jestli vůbec existuje
if (!$page) {
    // Hodnota promenne page neexistuje, proto nacteme vychozi hodnotu z konstanty
    $page = DEFAULT_PAGE_NAME;
}

// Abychom nakoukli také pod pokličku objektově-orientovaného programování, menu aplikace bude řešeno jako objekt třídy
// Nejprve souboru index zpřístupníme zdrojový kód souboru s definicí třídy Menu
// K tomuto účelu můžeme použít buď příkaz require nebo include
require_once './classes/Menu.php';

// Třída sama o sobě je jen definicí struktury objektu
// "Ozije" tedy az v momente, kdy z třídy vytvoříme objekt
// Je to něco jako Frankensteinovo monstrum - kostre je nutné vdechnout zivot
// Vytvoření objektu z třídy Menu
$menu = new Menu();

// Nastavení parametrů objektu Menu
// Objekt třídy Menu volá svou metodu addItem() a předává ji 2 parametry (1 - hodnotu promenne page, 2 - název stránky)
$menu->addMenuItem(DEFAULT_PAGE_NAME, "Úvodní stránka");
$menu->addMenuItem("informace", "Informace");
$menu->addMenuItem("fotogalerie", "Fotogalerie");
$menu->addMenuItem('kontakt', 'Kontakt');

// Nastavení aktivní stránky pro označení (zvýraznění) v HTML menu
$menu->setActiveItem($page);

// Zpřístupnění souboru podle hodnoty promenne page z URL
// Převedu hodnotu proměnné na řetězec reprezentující cestu k fyzickému souboru, který obsahuje příslušný zdrojový kód
// Např. tedy /data/kontakt.php
$file = "./data/".$page.".php";

// Overeni existence souboru
// Důvod je prosty, kdokoli muze URL libovolne prepisovat a hodnotu promenne page "podstrcit"
// Pokud existuje soubor podle podmínky, zpřístupním zde jeho zdrojový kód
if (file_exists($file)) {
    require_once $file;
} else {
    // Pokud soubor neexistuje, vložím chybový 404 
    include_once "./data/404.php";
}

// Vložím HTML patičku stránek
// HTML hlavičku stránek si samy vkládají volané soubory ze složky /data
require_once "./inc/bottom.inc.php"; 

// Zde konci prace souboru index.php a zároven práce interpreta jazyka PHP
// Vygenerovany vysledek (HTML) se zasila klientovi
exit;